@@ -1,5 +1,5 @@
 /* df - summarize free disk space
-   Copyright (C) 91, 1995-2008 Free Software Foundation, Inc.
+   Copyright (C) 91, 1995-2009 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -70,7 +70,7 @@ static bool file_systems_processed;
 /* If true, invoke the `sync' system call before getting any usage data.
    Using this option can make df very slow, especially with many or very
    busy disks.  Note that this may make a difference on some systems --
-   SunOS 4.1.3, for one.  It is *not* necessary on Linux.  */
+   SunOS 4.1.3, for one.  It is *not* necessary on GNU/Linux.  */
 static bool require_sync;
 
 /* Desired exit status.  */
@@ -231,18 +231,28 @@ excluded_fstype (const char *fstype)
   return false;
 }
 
+/* Return true if N is a known integer value.  On many file systems,
+   UINTMAX_MAX represents an unknown value; on AIX, UINTMAX_MAX - 1
+   represents unknown.  Use a rule that works on AIX file systems, and
+   that almost-always works on other types.  */
+static bool
+known_value (uintmax_t n)
+{
+  return n < UINTMAX_MAX - 1;
+}
+
 /* Like human_readable (N, BUF, human_output_opts, INPUT_UNITS, OUTPUT_UNITS),
    except:
 
     - If NEGATIVE, then N represents a negative number,
       expressed in two's complement.
-    - Otherwise, return "-" if N is UINTMAX_MAX.  */
+    - Otherwise, return "-" if N is unknown.  */
 
 static char const *
 df_readable (bool negative, uintmax_t n, char *buf,
 	     uintmax_t input_units, uintmax_t output_units)
 {
-  if (n == UINTMAX_MAX && !negative)
+  if (! known_value (n) && !negative)
     return "-";
   else
     {
@@ -393,8 +403,10 @@ show_dev (char const *disk, char const *mount_point,
       negate_available = false;
       available_to_root = available;
 
-      grand_fsu.fsu_files += total;
-      grand_fsu.fsu_ffree += available;
+      if (known_value (total))
+	grand_fsu.fsu_files += total;
+      if (known_value (available))
+	grand_fsu.fsu_ffree += available;
     }
   else
     {
@@ -419,19 +431,22 @@ show_dev (char const *disk, char const *mount_point,
       total = fsu.fsu_blocks;
       available = fsu.fsu_bavail;
       negate_available = (fsu.fsu_bavail_top_bit_set
-			  & (available != UINTMAX_MAX));
+			  & known_value (available));
       available_to_root = fsu.fsu_bfree;
 
-      grand_fsu.fsu_blocks += input_units * total;
-      grand_fsu.fsu_bfree  += input_units * available_to_root;
-      add_uint_with_neg_flag (&grand_fsu.fsu_bavail,
-			      &grand_fsu.fsu_bavail_top_bit_set,
-			      input_units * available, negate_available);
+      if (known_value (total))
+	grand_fsu.fsu_blocks += input_units * total;
+      if (known_value (available_to_root))
+	grand_fsu.fsu_bfree  += input_units * available_to_root;
+      if (known_value (available))
+	add_uint_with_neg_flag (&grand_fsu.fsu_bavail,
+				&grand_fsu.fsu_bavail_top_bit_set,
+				input_units * available, negate_available);
     }
 
   used = UINTMAX_MAX;
   negate_used = false;
-  if (total != UINTMAX_MAX && available_to_root != UINTMAX_MAX)
+  if (known_value (total) && known_value (available_to_root))
     {
       used = total - available_to_root;
       negate_used = (total < available_to_root);
@@ -446,7 +461,7 @@ show_dev (char const *disk, char const *mount_point,
 	  width, df_readable (negate_available, available,
 			      buf[2], input_units, output_units));
 
-  if (used == UINTMAX_MAX || available == UINTMAX_MAX)
+  if (! known_value (used) || ! known_value (available))
     ;
   else if (!negate_used
 	   && used <= TYPE_MAXIMUM (uintmax_t) / 100
@@ -973,17 +988,21 @@ main (int argc, char **argv)
     {
       int i;
 
-      /* stat all the given entries to make sure they get automounted,
-	 if necessary, before reading the file system table.  */
+      /* Open each of the given entries to make sure any corresponding
+	 partition is automounted.  This must be done before reading the
+	 file system table.  */
       stats = xnmalloc (argc - optind, sizeof *stats);
       for (i = optind; i < argc; ++i)
 	{
-	  if (stat (argv[i], &stats[i - optind]))
+	  int fd = open (argv[i], O_RDONLY | O_NOCTTY);
+	  if (fd < 0 || fstat (fd, &stats[i - optind]))
 	    {
 	      error (0, errno, "%s", quote (argv[i]));
 	      exit_status = EXIT_FAILURE;
 	      argv[i] = NULL;
 	    }
+	  if (0 <= fd)
+	    close (fd);
 	}
     }
 
